==> nrich-registry-2.5.0-sources.jar: net/croz/nrich/registry/history/controller/RegistryHistoryController.java <==
/*
 *  Copyright 2020-2023 CROZ d.o.o, the original author or authors.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package net.croz.nrich.registry.history.controller;

import lombok.RequiredArgsConstructor;
import net.croz.nrich.registry.api.history.model.EntityWithRevision;
import net.croz.nrich.registry.api.history.request.ListRegistryHistoryRequest;
import net.croz.nrich.registry.api.history.service.RegistryHistoryService;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import jakarta.validation.Valid;

@RequiredArgsConstructor
@RequestMapping("${nrich.registry.history.endpoint-path:nrich/registry/history}")
@RestController
public class RegistryHistoryController {

    private final RegistryHistoryService registryHistoryService;

    @PostMapping("list")
    public <T> Page<EntityWithRevision<T>> historyList(@RequestBody @Valid ListRegistryHistoryRequest request) {
        return registryHistoryService.historyList(request);
    }
}

==> nrich-registry-2.9.0-sources.jar: net/croz/nrich/registry/history/controller/RegistryHistoryController.java <==
/*
 *  Copyright 2020-2023 CROZ d.o.o, the original author or authors.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package net.croz.nrich.registry.history.controller;

import lombok.RequiredArgsConstructor;
import net.croz.nrich.registry.api.history.model.EntityWithRevision;
import net.croz.nrich.registry.api.history.request.ListRegistryHistoryRequest;
import net.croz.nrich.registry.api.history.service.RegistryHistoryService;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import jakarta.validation.Valid;

@RequiredArgsConstructor
@RequestMapping("${nrich.registry.history.endpoint-path:nrich/registry/history}")
@RestController
public class RegistryHistoryController {

    private final RegistryHistoryService registryHistoryService;

    @PostMapping("list")
    public Page<EntityWithRevision<Object>> historyList(@RequestBody @Valid ListRegistryHistoryRequest request) {
        return registryHistoryService.historyList(request);
    }
}
